.. _api-reference:

API
===

The alphalens API is organized into four modules:

* Tear Sheets: :mod:`alphalens.tears`
* Performance Metrics: :mod:`alphalens.performance`
* Plotting Functions: :mod:`alphalens.plotting`
* Utilities: :mod:`alphalens.utils`

Tear Sheets
-----------

Alphalens combines key metrics in plots in thematic and summary tear sheets.

.. automodule:: alphalens.tears
    :members:
    :undoc-members:
    :show-inheritance:

Performance Metrics
-------------------

The module :mod:`alphalens.performance` provides performance and risk metrics.

.. automodule:: alphalens.performance
    :members:
    :undoc-members:
    :show-inheritance:

Plotting Functions
------------------

The module :mod:`alphalens.plotting` facilitates the visualization of performance metrics.

.. automodule:: alphalens.plotting
    :members:
    :undoc-members:
    :show-inheritance:

Utilities
---------

The module :mod:`alphalens.utils` contains helper functions, e.g. to format factor data into the requisite input format.

.. automodule:: alphalens.utils
    :members:
    :undoc-members:
    :show-inheritance:
